#
# spec file for package libnl3
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libnl3
%define lname	libnl3-200
%define with_tools 1
Version:        3.2.24
Release:        1.1
Summary:        Convenience library for working with Netlink sockets
License:        LGPL-2.1 and GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://www.carisma.slowglass.com/~tgr/libnl/

#Git-Clone:	git://git.infradead.org/users/tgr/libnl
#Git-Clone:	git://github.com/tgraf/libnl
#DL-URL:	http://www.carisma.slowglass.com/~tgr/libnl/files/
Source:         libnl-%version.tar.xz
Source2:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  flex >= 2.5.19
BuildRequires:  pkgconfig >= 0.21
# Only used if python/ subdir would be built, which is not and
# is marked as 
# "NOTE: The python wrapper is experimental and may or may not work."
# BuildRequires:  python-devel >= 2.6
BuildRequires:  xz
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif

%description
The libnl suite is a collection of libraries providing APIs to
Netlink protocol based Linux kernel interfaces.

%package -n %lname
Summary:        Convenience library for working with Netlink sockets
License:        LGPL-2.1
Group:          System/Libraries
Requires:       libnl-config >= %version

%description -n %lname
The libnl suite is a collection of libraries providing APIs to
netlink protocol based Linux kernel interfaces.

%package devel
Summary:        Libraries and headers for libnl
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Provides:       libnl-devel = %version-%release
# Starting with libnl3(-3.2), no more conflicts

%description devel
The libnl suite is a collection of libraries providing APIs to
Netlink protocol based Linux kernel interfaces.

%if %with_tools
#
# Only one of the libnl packages should create the config and tools.
#

%package -n libnl-config
Summary:        Name maps for libnl
License:        LGPL-2.1 and GPL-2.0
Group:          Productivity/Networking/Security
%if 0%{?suse_version} >= 1130
BuildArch:      noarch
%endif

%description -n libnl-config
This package contains configuration files for libnl and programs using
the same; in particular
- name maps for class-ids -- class-names (like /etc/services)
- aliases for locations within a packet (ip6.dst => byte offset)

%package -n libnl-tools
Summary:        Command line utilities to directly work with Netlink
License:        GPL-2.0
Group:          Productivity/Networking/Security

%description -n libnl-tools
Various test program with which the functionality of libnl is
demonstrated.

%endif

%prep
%if 0%{?__xz:1}
%setup -qn libnl-%version
%else
tar -xf "%{S:0}" --use=xz;
%setup -DTqn libnl-%version
%endif

%build
%configure --disable-static
make %{?_smp_mflags} pkglibdir="%_libdir/%lname"

%install
b="%buildroot";
make install DESTDIR="%buildroot" pkglibdir="%_libdir/%lname";
find "$b" -iname "*.la" -delete;
%if !%with_tools
rm -Rf "$b/%_sysconfdir/libnl";
rm -Rf "$b/%_sbindir" "$b/%_mandir/man8";
%endif
%if 0%{?fdupes:1}
%fdupes %buildroot/%_prefix
%endif

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libnl*.so.200*
%_libdir/%lname

%files devel
%defattr(-,root,root)
%_includedir/%name
%_libdir/libnl*.so
%_libdir/pkgconfig/*

%if %with_tools

%files -n libnl-config
%defattr(-,root,root)
%dir %_sysconfdir/libnl
%config %_sysconfdir/libnl/*

%files -n libnl-tools
%defattr(-,root,root)
%_mandir/man*/*
%_sbindir/*
%endif

%changelog
* Fri Apr 25 2014 dmueller@suse.com
- remove python-devel dependency
* Sun Mar  9 2014 jengelh@inai.de
- Update to new upstream release 3.2.24
  * Add support for: ingress qdiscs, veth links, link network
  namespaces, tc action (general), mirred tc action, u32 tc action,
  fq_codel qdisc
* Tue Nov 26 2013 jengelh@inai.de
- Update to new upstream release 3.2.23
  * Add macvlan and VXVLAN support
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 3.2.22
  * ct: add ICMPv6 type,code and ID
  * attr: Provide nla_is_nested() function
  * bridge: Support the new bridging attributes
  * bridge: Provide rtnl_link_bridge_alloc()
  * vlan: Provide rtnl_link_vlan_alloc()
  * bond: Provide rtnl_link_bond_alloc()
  * attr: Add nla_nest_cancel() to remove partially added nested
  attributes
- Remove 0001-Add-symbol-version-maps-to-libnl.patch
  (merged upstream)
* Thu Mar  7 2013 jengelh@inai.de
- Add preliminary symbol versioning for libnl
  (0001-Add-symbol-version-maps-to-libnl.patch)
* Fri Jan 25 2013 jengelh@inai.de
- Update to new upstream release 3.2.21
  * SocketCAN support
  * Add link carrier support
* Sun Nov 25 2012 jengelh@inai.de
- Update to new upstream release 3.2.16
  * Optional hashtable backend for caches
  * Improved netlink expectations support
  * Extended AF_BRIDGE support for link and neighbour caches
  * Better thread safety in module registration operations
* Wed Nov 14 2012 jengelh@inai.de
- Update to new upstream release 3.2.14
  * This release contains bugfixes and adds support for some new link
  features.
* Tue Oct  9 2012 jengelh@inai.de
- Update to new upstream release 3.2.13
  * More clean NL_AUTO_PORT and NL_AUTO_SEQ usage in nl_complete_msg
  * genl_ctrl_probe_by_name: fix checking of genlmsg_put() return value
* Fri Aug 31 2012 jengelh@inai.de
- Update to new upstream release 3.2.12
  * Add new API to retrieve versioning information at runtime
  suitable for python ctype.
* Tue Jun 19 2012 jengelh@inai.de
- Update to new upstream release 3.2.11
  * add fwmark mask support
  * genl: add genlmsg_hdr(), genlmsg_user_hdr(), genlmsg_user_data(),
  and genlmsg_user_datalen()
  * genl: Export genl_ops_resolve() and genl_mngt_resolve() in header
  * rtnl_link_(get|set)_weight is deprecated in libnl
* Fri May 11 2012 vuntz@opensuse.org
- Update to version 3.2.9:
  * Fix return value of nl_recvmsgs()
* Sat May  5 2012 jengelh@medozas.de
- Update to new upstream release 3.2.8
  * Support plug qdisc - queue traffic until explicit release
* Wed Feb  8 2012 jengelh@medozas.de
- Update to new upstream release 3.2.7
  * link: fix regression in link message parser
  * nl_addr_cmp: handle prefix length during address comparison
  * avoid dangling co_major_cache reference to NL_AUTO_PROVIDE caches
  * dsmark: Add missing declarations for
  rtnl_class_dsmark_(get|set)_bitmask
  * rtnl_link_bond_add: allow to allocate bond name in case NULL
  is given
  * link: allow to add/get linkinfo of unknown type
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Jan  3 2012 adrian@suse.de
- add dangling-co_major_cache-reference fix required by ntrack
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 11 2011 jengelh@medozas.de
- Update to new upstream release 3.2.3
  * Add missing libnl-cli-3.0 pkgconfig file
  * Fix memory leaks durgin rtnl_addr object freeing
* Wed Sep 21 2011 jengelh@medozas.de
- Update to new upstream release 3.2.1
  * new API to create/enslave/release bonding devices
* Tue Sep 20 2011 jengelh@medozas.de
- Relax Requires in libnl3-devel
* Wed Sep 14 2011 jengelh@medozas.de
- Update to libnl-3.2
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Dec 16 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Add baselib definitions for SPARC
- Enable parallel building
* Fri Jun 12 2009 coolo@novell.com
- fix build with glibc 2.10
* Thu Feb  5 2009 bphilips@suse.de
- baselibs.conf: create -32bit packages. Required to compile Intel
  WiMax tools.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Nov 11 2008 jpr@novell.com
- Add baselibs.conf (bnc#443023)
* Thu Oct  2 2008 maw@suse.de
- Install libraries in %%_lib, not %%{_libdir} (bnc#428433).
* Fri Feb  1 2008 coolo@suse.de
- update to 1.1:
  o patches went upstream
  o Generic netlink support
  o Route Addition/Deletion
  o Fixed reference counting while objects stay in caches.
  ... tons of other fixes
* Fri Jan 25 2008 adrian@suse.de
- fix changelog entries order
* Wed Oct  3 2007 maw@suse.de
- Apply libnl.route.metric-overflow.patch with -p1.
* Sat Aug 25 2007 olh@suse.de
- remove incomplete copies of kernel headers
  linux/types.h were needed
* Fri Aug 24 2007 olh@suse.de
- include linux/types.h
  do not redefine typedefs
  use stddef.h offsetof
  fix out of bounds access in route metric functions
  fix incorrect char usage in nl_str2af
  remove compiler warnings by checking vasprintf return value
* Wed Aug 22 2007 dmueller@suse.de
- fix accesses of free'd memory which crash NetworkManager-kde
* Wed Aug 22 2007 dmueller@suse.de
- update to 1.0-pre6:
  * fixes write after delete crashes
  * fixes realloc() handling
  * fixes format string warnings
  * fixes invalid free in nl_addr_parse for AF_UNSPEC addresses
  * fixes double nlmsg_free() in nl_recvmsgs() while receiving
    a multipart message and the read was interrupted.
* Sun Feb 19 2006 ro@suse.de
- fix build on ia64, ppc64, s390x
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 yxu@suse.de
- fixed conflicting type definition
* Fri Nov  4 2005 rml@suse.de
- Update to 1.0-pre5
* Mon Oct 31 2005 gekker@suse.de
- Initial import into autobuild Version 1.0-pre3
- Patch makefile
